@@ -198,10 +198,14 @@ class CarteTransOperator(CarteBaseOperator):
             self.log.info(self.LOG_TEMPLATE, status_desc, self.trans)
             self._log_logging_string(status['logging_string'])
 
-            if status_desc not in self.FINISHED_STATUSES:
+            if status_desc not in self.END_STATUSES:
                 self.log.info('Sleeping 5 seconds before ask again')
                 time.sleep(5)
 
         if 'error_desc' in status and status['error_desc']:
             self.log.error(self.LOG_TEMPLATE, status['error_desc'], self.trans)
             raise AirflowException(status['error_desc'])
+
+        if status_desc in self.ERRORS_STATUSES:
+            self.log.error(self.LOG_TEMPLATE, status['status_desc'], self.trans)
+            raise AirflowException(status['status_desc'])
